@@ -131,6 +131,18 @@ def create_merchant_customer_transaction_upstream_for_merchant(transaction_detai
     
     __create_upstream(transaction_details, CUSTOMER_TRANSACTION_TEMPLATE, MERCHANT_DATASET, final_table_name, 
                       update_datetime=update_datetime, Reverted=False, RevertedDateTime=None)
+    
+def create_merchant_customer_transaction_reveted_upstream_for_merchant(transaction_details, reverted_datetime, update_datetime=None):
+    if update_datetime is None:
+        update_datetime     = datetime.now()
+        
+    table_name          = CUSTOMER_TRANSACTION_TEMPLATE
+    merchant_acct       = transaction_details.transact_merchant_acct
+    account_code        = merchant_acct.account_code.replace('-','')
+    final_table_name    = '{}_{}_{}'.format(table_name, account_code, update_datetime.strftime('%Y%m%d'))
+    
+    __create_upstream(transaction_details, CUSTOMER_TRANSACTION_TEMPLATE, MERCHANT_DATASET, final_table_name, 
+                      update_datetime=update_datetime, Reverted=True, RevertedDateTime=reverted_datetime)    
 
 def create_merchant_customer_reward_upstream_for_merchant(transaction_details, reward_details, update_datetime=None):
     if update_datetime is None:
